/*
 * Please cite:
 * Zen, G., Ricci, E. 
 * Earth Mover’s Prototypes: a Convex Learning Approach for Discovering Activity Patterns in Dynamic Scenes.
 * IEEE Conference on Computer Vision and Pattern Recognition (CVPR), 2011.
 * http://disi.unitn.it/~zen/emd.html
 
 This file is part of EMP (Earth Mover's Prototypes).

 EMP is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 EMP is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with EMP.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <iostream>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>


#include "param.h"

//----------------------------------------------------------------------------------------------

parameters::parameters(){
    init();
}
//----------------------------------------------------------------------------------------------

parameters::parameters(char* file_config){
    
    load_parameters_from_file(file_config);
}
//----------------------------------------------------------------------------------------------

// set default values
void parameters::init() {

    gamma = 0;
    strcpy(clustering_type, "L1");
    loadfilesort = false;
}
//----------------------------------------------------------------------------------------------

void parameters::load_parameters_from_file(char* file_config) {

    FILE* pf = fopen(file_config, "r");
    if (pf == NULL) {
        fprintf(stderr, "\nError in load_parameters_from_file: file %s not found\n", file_config);
        exit(1);
    }
    //--- 

    while (!feof(pf)) {
        char line[200];
        char *pdata;
        fgets(line, 200, pf);
        if (line[0] == '#' || line[0] == ' ' || line[0] == '\n')
            continue;

        pdata = strtok(line, "=");

        if (strcmp(pdata, "FILE_DATA") == 0) {
            pdata = strtok(NULL, "=\n");
            strcpy(file_data, pdata);
        }
        else if (strcmp(pdata, "FILE_SORT") == 0) {
            pdata = strtok(NULL, "=\n");
            strcpy(file_sort, pdata);
            loadfilesort = true;
        }
        else if (strcmp(pdata, "OUTPUT_DIR") == 0) {
            pdata = strtok(NULL, "=\n");
            strcpy(output_dir, pdata);
        }//
        else if (strcmp(pdata, "CLUSTERING_TYPE") == 0) {
            pdata = strtok(NULL, "=\n");
            strcpy(clustering_type, pdata);
        }//
        else if (strcmp(pdata, "GAMMA") == 0) {
            pdata = strtok(NULL, "=\n");
            gamma = atof(pdata);
        } 
        else if (strcmp(pdata, "N") == 0) {
            pdata = strtok(NULL, "=\n");
            N = atoi(pdata);
        } 
        else if (strcmp(pdata, "D") == 0) {
            pdata = strtok(NULL, "=\n");
            D = atoi(pdata);
        } 
        else if (strcmp(pdata, "Np") == 0) {
            pdata = strtok(NULL, "=\n");
            Np = atoi(pdata);
        }
        //
        else if (strcmp(pdata, "FILE_RES_CLUSTERING") == 0) {
            pdata = strtok(NULL, "=\n");
            strcpy(file_res_clustering, pdata);
        }
        else if (strcmp(pdata, "FILE_GT") == 0) {
            pdata = strtok(NULL, "=\n");
            strcpy(file_groundtruth, pdata);
        }        
        else {
            fprintf(stderr, "\nWarning: param \'%s\' not considered. ", pdata);
        }
    }
}

